# Hotsos

Use hotsos to implement repeatable analysis and extract useful information from common cloud applications and subsystems. Write analyses scenarios using a high-level language, leveraging Python libaries to help extract information. A catalog of analysis implementations is included. The code is organised as “plugins” that implement functionality specific to an application or subsystem.

## Documentation

Installation and Usage: https://hotsos.readthedocs.io/en/latest/install/index.html

Contributing: https://hotsos.readthedocs.io/en/latest/contrib/index.html

Full documentation: https://hotsos.readthedocs.io/en/latest/
